==> polymer-resource-pack-extras-0.15.1+1.21.11-sources.jar: eu/pb4/polymer/resourcepack/extras/api/format/font/BitmapProvider.java <==
package eu.pb4.polymer.resourcepack.extras.api.format.font;

import com.mojang.serialization.Codec;
import com.mojang.serialization.MapCodec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import java.util.ArrayList;
import java.util.List;
import net.minecraft.class_2960;

public record BitmapProvider(class_2960 file, List<String> chars, int ascent, int height) implements FontProvider {
    public static final MapCodec<BitmapProvider> CODEC = RecordCodecBuilder.mapCodec(instance -> instance.group(
            class_2960.field_25139.fieldOf("file").forGetter(BitmapProvider::file),
            Codec.STRING.listOf().fieldOf("chars").forGetter(BitmapProvider::chars),
            Codec.INT.fieldOf("ascent").forGetter(BitmapProvider::ascent),
            Codec.INT.optionalFieldOf("height", 8).forGetter(BitmapProvider::height)
    ).apply(instance, BitmapProvider::new));


    public BitmapProvider(class_2960 file, List<String> chars, int ascent) {
        this(file, chars, ascent, 8);
    }

    @Override
    public MapCodec<? extends FontProvider> codec() {
        return CODEC;
    }

    public static eu.pb4.polymer.resourcepack.extras.api.format.font.BitmapProvider.Builder builder(class_2960 file) {
        return new eu.pb4.polymer.resourcepack.extras.api.format.font.BitmapProvider.Builder(file);
    }

    public static class Builder implements FontProvider.Builder {
        private final List<String> chars = new ArrayList<>();
        private final class_2960 file;
        private int ascent = 7;
        private int height = 8;

        private Builder(class_2960 file) {
            this.file = file;
        }

        public eu.pb4.polymer.resourcepack.extras.api.format.font.BitmapProvider.Builder chars(String string) {
            this.chars.add(string);
            return this;
        }

        public eu.pb4.polymer.resourcepack.extras.api.format.font.BitmapProvider.Builder height(int height) {
            this.height = height;
            return this;
        }

        public eu.pb4.polymer.resourcepack.extras.api.format.font.BitmapProvider.Builder ascent(int ascent) {
            this.ascent = ascent;
            return this;
        }

        public BitmapProvider build() {
            return new BitmapProvider(this.file, this.chars, this.ascent, this.height);
        }
    }
}

==> polymer-resource-pack-extras-0.15.2+1.21.11-sources.jar: eu/pb4/polymer/resourcepack/extras/api/format/font/BitmapProvider.java <==
package eu.pb4.polymer.resourcepack.extras.api.format.font;

import com.mojang.serialization.Codec;
import com.mojang.serialization.MapCodec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import java.util.ArrayList;
import java.util.List;
import net.minecraft.class_2960;

public record BitmapProvider(class_2960 file, List<String> chars, int ascent, int height) implements FontProvider {
    public static final MapCodec<BitmapProvider> CODEC = RecordCodecBuilder.mapCodec(instance -> instance.group(
            class_2960.field_25139.fieldOf("file").forGetter(BitmapProvider::file),
            Codec.STRING.listOf().fieldOf("chars").forGetter(BitmapProvider::chars),
            Codec.INT.fieldOf("ascent").forGetter(BitmapProvider::ascent),
            Codec.INT.optionalFieldOf("height", 8).forGetter(BitmapProvider::height)
    ).apply(instance, BitmapProvider::new));


    public BitmapProvider(class_2960 file, List<String> chars, int ascent) {
        this(file, chars, ascent, 8);
    }

    public static BitmapProvider.Builder builder(class_2960 file) {
        return new BitmapProvider.Builder(file);
    }

    @Override
    public MapCodec<? extends FontProvider> codec() {
        return CODEC;
    }

    public static class Builder implements FontProvider.Builder {
        private final List<String> chars = new ArrayList<>();
        private final class_2960 file;
        private int ascent = 7;
        private int height = 8;

        private Builder(class_2960 file) {
            this.file = file;
        }

        public BitmapProvider.Builder chars(String string) {
            this.chars.add(string);
            return this;
        }

        public BitmapProvider.Builder height(int height) {
            this.height = height;
            return this;
        }

        public BitmapProvider.Builder ascent(int ascent) {
            this.ascent = ascent;
            return this;
        }

        public BitmapProvider build() {
            return new BitmapProvider(this.file, this.chars, this.ascent, this.height);
        }
    }
}
